#ifndef WFRAME_H
#define WFRAME_H

#include <QtGui/qmainwindow.h>

class WFrame : public QMainWindow
{
  // macro Q_OBJECT indispensable pour sp&eacute;cifier &agrave; Qt l'utilisation du m&eacute;canisme interne de 
  // communication entre les classes.

    public:

  /**
   * @brief Constructeur de notre classe.
   * Initialise les menus, la toolbar et les zones images et d'information.
   * @param parent : parent de cette fen&ecirc;tre : ici 0 signifie que c'est la fen&ecirc;tre principale
   * @param applicationPath : chemin absolu de lancement de cette application
   */
  WFrame(QMainWindow* parent = 0,const QString& applicationPath= "", Qt::WFlags = Qt::Window );

  /**
   * @brief Destructeur de classe.
   */
  virtual ~WFrame();

 private:

  /** @brief Pointeur sur le widget de la palette  */
  Palette* m_palette;

  /** @brief Pointeur sur le widget de la visu */	
  Visu2D* m_visu2d;

  /** @brief Pointeur sur le widget des statistiques */	
  WStatistiques *m_wStatistiques;

  /** @brief Pointeur sur notre image  */
  Image *m_pImage;

  /** @brief chemin absolu de lancement de cette application */
  QString m_applicationPath;

  /** @brief Classe d'&eacute;venements associ&eacute;s au bouton Rectangle  */
  QAction *m_actionRectangle;

  /** @brief Classe d'&eacute;venements associ&eacute;s au bouton Ellipse */
  QAction *m_actionEllipse;

  /** @brief Classe d'&eacute;venements associ&eacute;s au bouton Carre  */
  QAction *m_actionCarre;

  /** @brief Classe d'&eacute;venements associ&eacute;s au bouton Cercle  */
  QAction *m_actionCercle;

  /** @brief Classe d'&eacute;venements associ&eacute;s au bouton Polygone  */
  QAction *m_actionPolygone;

  /** @brief Pointeur utilis pour mmoriser la forme en cours ; pas de bouton directement associ */
  QAction *m_actionFormeEnCours;

  /** @brief Classe d'&eacute;venements associ&eacute;s au mode dplacement de la forme */
  QAction *m_actionDeplaceForme;

  /** @brief Classe d'&eacute;venements associ&eacute;s au mode selection de la couleur */
  QAction *m_actionSelectCouleur;

  /** @brief Classe d'&eacute;venements associ&eacute;s au bouton d'effacement des formes reprsentes */
  QAction *m_actionEffaceFormes;

  /** @brief Classe d'&eacute;venements associ&eacute;s au mode ajoute nouvelle forme */
  QAction *m_actionModeAjoute;

  /** @brief Label associ&eacute; &agrave; la barre de status  */
  QLabel* m_label;

  public slots:
  /**
   * @brief M&eacute;thode appel&eacute;e lors de la selection d'une nouvelle image.
   * @return true si l'image est correcte, false sinon
   */
  bool OuvreImage();

  /**
   * @brief M&eacute;thode appel&eacute;e par visu2d lorsque un changement de la barre d'info est n&eacute;cessaire
   * @param s nouvelle string &agrave; affecter &agrave; la barre d'infos
   */
  void MAJBarreInfo(const QString& s);

  /**
   * @brief M&eacute;thode appel&eacute;e lors du clic sur le bouton Rectangle de la toolbar
   */
  void ClicRectangle();

  /**
   * @brief M&eacute;thode appel&eacute;e lors du clic sur le bouton Ellipse de la toolbar
   */
  void ClicEllipse();

  /**
   * @brief M&eacute;thode appel&eacute;e lors du clic sur le bouton Carre de la toolbar
   */
  void ClicCarre();

  /**
   * @brief M&eacute;thode appel&eacute;e lors du clic sur le bouton Cercle de la toolbar
   */
  void ClicCercle();

  /**
   * @brief M&eacute;thode appel&eacute;e lors du clic sur le bouton Polygone de la toolbar
   */
  void ClicPolygone();

  /**
   * @brief Methode appel&eacute;e lors de la mise  jour de la palette. 
   */
  void MAJPalette();

  /**
   * @brief Appele lorsque la slection a chang ; pour mettre  jour la fentre de stat. 
   */
  void MAJStatistiques(Selection*, int);

 protected:
  /** @brief Initialise les menus */
  void InitMenus();

  /** @brief Initialise la barre d'outils  */
  void InitToolBar();

  /** @brief Change le type de forme slectionn  */
  void SetType(QAction* tb, TYPE_FORME type);
};

#endif // WFRAME_H
